#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 clash-lib
version:              1.4.0
visibility:           public
id:                   clash-lib-1.4.0-AK9vbzUIucCKmcJ0VN0e2F
key:                  clash-lib-1.4.0-AK9vbzUIucCKmcJ0VN0e2F
license:              BSD-2-Clause
copyright:
    Copyright © 2012-2016, University of Twente,
    2016-2019, Myrtle Software Ltd,
    2017-2019, QBayLogic B.V., Google Inc.

maintainer:           QBayLogic B.V. <devops@qbaylogic.com>
author:               The Clash Authors
homepage:             https://clash-lang.org/
synopsis:
    Clash: a functional hardware description language - As a library

description:
    Clash is a functional hardware description language that borrows both its
    syntax and semantics from the functional programming language Haskell. The
    Clash compiler transforms these high-level descriptions to low-level
    synthesizable VHDL, Verilog, or SystemVerilog.

    Features of Clash:

    * Strongly typed, but with a very high degree of type inference, enabling both
    safe and fast prototyping using concise descriptions.

    * Interactive REPL: load your designs in an interpreter and easily test all
    your component without needing to setup a test bench.

    * Higher-order functions, with type inference, result in designs that are
    fully parametric by default.

    * Synchronous sequential circuit design based on streams of values, called
    @Signal@s, lead to natural descriptions of feedback loops.

    * Support for multiple clock domains, with type safe clock domain crossing.


    This package provides:

    * The CoreHW internal language: SystemF + Letrec + Case-decomposition

    * The normalisation process that brings CoreHW in a normal form that can be
    converted to a netlist

    * Blackbox/Primitive Handling


    Front-ends (for: parsing, typecheck, etc.) are provided by separate packages:

    * <https://hackage.haskell.org/package/clash-ghc GHC/Haskell Frontend>

    * <https://github.com/christiaanb/Idris-dev Idris Frontend>


    Prelude library: <https://hackage.haskell.org/package/clash-prelude>

category:             Hardware
abi:                  4bd6956f0c0e30d0caad42e7a3c301d3
exposed:              True
exposed-modules:
    Clash.Annotations.BitRepresentation.ClashLib Clash.Backend
    Clash.Backend.SystemVerilog Clash.Backend.VHDL
    Clash.Backend.Verilog Clash.Core.DataCon Clash.Core.EqSolver
    Clash.Core.Evaluator.Types Clash.Core.FreeVars Clash.Core.Literal
    Clash.Core.Name Clash.Core.PartialEval
    Clash.Core.PartialEval.AsTerm Clash.Core.PartialEval.Monad
    Clash.Core.PartialEval.NormalForm Clash.Core.Pretty
    Clash.Core.Subst Clash.Core.Term Clash.Core.TermInfo
    Clash.Core.TermLiteral Clash.Core.TermLiteral.TH
    Clash.Core.Termination Clash.Core.TyCon Clash.Core.Type
    Clash.Core.TysPrim Clash.Core.Util Clash.Core.Var Clash.Core.VarEnv
    Clash.Debug Clash.Driver Clash.Driver.Manifest Clash.Driver.Types
    Clash.Edalize.Edam Clash.Netlist Clash.Netlist.BlackBox
    Clash.Netlist.BlackBox.Parser Clash.Netlist.BlackBox.Types
    Clash.Netlist.BlackBox.Util Clash.Netlist.Id
    Clash.Netlist.Id.Common Clash.Netlist.Id.Internal
    Clash.Netlist.Id.SystemVerilog Clash.Netlist.Id.VHDL
    Clash.Netlist.Id.Verilog Clash.Netlist.Types Clash.Netlist.Util
    Clash.Normalize Clash.Normalize.DEC
    Clash.Normalize.PrimitiveReductions Clash.Normalize.Strategy
    Clash.Normalize.Transformations Clash.Normalize.Types
    Clash.Normalize.Util Clash.Pretty Clash.Primitives.DSL
    Clash.Primitives.GHC.Int Clash.Primitives.GHC.Literal
    Clash.Primitives.GHC.Word Clash.Primitives.Intel.ClockGen
    Clash.Primitives.Sized.ToInteger Clash.Primitives.Sized.Vector
    Clash.Primitives.Types Clash.Primitives.Util
    Clash.Primitives.Verification Clash.Rewrite.Combinators
    Clash.Rewrite.Types Clash.Rewrite.Util Clash.Rewrite.WorkFree
    Clash.Unique Clash.Util Clash.Util.Graph Clash.Util.Interpolate
    Data.Text.Prettyprint.Doc.Extra

hidden-modules:
    Clash.Annotations.TopEntity.Extra Control.Applicative.Extra
    Data.Aeson.Extra Data.List.Extra Data.Map.Ordered.Extra
    Data.Primitive.ByteArray.Extra Data.Semigroup.Monad.Extra
    Data.Set.Ordered.Extra GHC.BasicTypes.Extra GHC.SrcLoc.Extra
    Paths_clash_lib

import-dirs:          /usr/lib/ghc-8.10.4/site-local/clash-lib-1.4.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/clash-lib-1.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/clash-lib-1.4.0
hs-libraries:         HSclash-lib-1.4.0-AK9vbzUIucCKmcJ0VN0e2F
depends:
    aeson-1.5.6.0-5UhD0HeD84KFPVsjqEyp8O
    aeson-pretty-0.8.8-3LAxK2wPfpAFHhPWkkScTH
    ansi-terminal-0.11-LkRk8FVsPUc43vjyLHpLwy array-0.5.4.0
    attoparsec-0.13.2.5-J6b14THaxvY185NePfXLop base-4.14.1.0
    base16-bytestring-1.0.1.0-96D88dIF01ZC6PmS2McW12 binary-0.8.8.0
    bytestring-0.10.12.0 clash-prelude-1.4.0-HU0N2Y8VPfb5EG5NRW7J28
    concurrent-supply-0.1.8-JP9JVdFBxiBAzhjLdGKWsP containers-0.6.2.1
    cryptohash-sha256-0.11.102.0-KyD7Jeud6HcI0PDce3tmz5
    data-binary-ieee754-0.4.4-HlSlHq1qDaTKAKUZNW5rdz
    data-default-0.7.1.1-DVZWGRf90hqGebpGTaPvOV deepseq-1.4.4.0
    directory-1.3.6.0 dlist-1.0-KFY6kePYM7gDQLIElBL83C
    errors-2.3.0-1jMMqiGok7nGSgO7igf65q exceptions-0.10.4
    extra-1.7.9-2iz2eeUzuSk6vWcWekkLY3 filepath-1.4.2.1 ghc-8.10.4
    ghc-boot-th-8.10.4 hashable-1.3.1.0-1TzQw0rlraYH9EvMt0jxBh
    haskell-src-meta-0.8.7-DGBTtLzQDdD8xvOFL7q2Zr
    hint-0.9.0.4-Efagf9sTZzV1EFNeT6Kej8 integer-gmp-1.0.3.0
    interpolate-0.2.1-AtudXzHDzoV1pxe0362LlH
    lens-4.19.2-GBzUOPAiptq9QOgOkivzaZ mtl-2.2.2
    ordered-containers-0.2.2-GyU6swLq6k0DcCVw8rbPro
    parsers-0.12.10-Hie1ki7uw2N1JEethNT4Ik
    pretty-show-1.10-EhdS2ToA2sEFyivshN51pj
    prettyprinter-1.7.0-78If9KczRn9JWdJ0ftiWq7
    primitive-0.7.1.0-6UD0eBDEpnYKdWwYIx7Zvv process-1.6.9.0
    reducers-3.12.3-LQwTHcRmolZ9ZW7vSaa9e3 template-haskell-2.16.0.0
    temporary-1.3-AiDcTNSVV72Gyr4sgrSmy6
    terminal-size-0.3.2.1-HihNy0RThZk4O1UkYpAxTd text-1.2.4.1
    text-show-3.9-5OGnWfkJerEFIZjz9zIquy time-1.9.3
    transformers-0.5.6.2 trifecta-2.1.1-GQXC0INVoUv8brSiCVljj3
    unordered-containers-0.2.13.0-ApNkHwNvshX8NJ7lvcglMy
    utf8-string-1.0.2-7pqBkplor7g1hjwTjVt3SV
    vector-0.12.2.0-6b7mFy2cENT3vKiDJ1nfAK
    vector-binary-instances-0.2.5.1-35vbdVpKLfWK38VPC7PZTv

haddock-interfaces:   /usr/share/doc/haskell-clash-lib/html/clash-lib.haddock
haddock-html:         /usr/share/doc/haskell-clash-lib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

